# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/event_contracts/v1/event_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/event_contracts/v1/event_contracts_v1.proto\x12\"strmprivacy.api.event_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xe8\x02\n\x19ListEventContractsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x11\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12M\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01\x12?\n\nschema_ref\x18\x06 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x01\x12\x37\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01\x12\x14\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01\x12\x17\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01\"a\n\x1aListEventContractsResponse\x12\x43\n\x0f\x65vent_contracts\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\"m\n\x17GetEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12:\n\x03ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\"u\n\x18GetEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x8c\x01\n\x1a\x43reateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x42\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x12\n\nproject_id\x18\x03 \x01(\t\"x\n\x1b\x43reateEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\xe3\x01\n\x1aUpdateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12G\n\x0e\x65vent_contract\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContractB\x03\xe0\x41\x02\x12\x15\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02\x12\x34\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02\"x\n\x1bUpdateEventContractResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x15\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03\"\x9f\x01\n\x1c\x41\x63tivateEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x1d\x41\x63tivateEventContractResponse\"\x9d\x01\n\x1a\x44\x65leteEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1d\n\x1b\x44\x65leteEventContractResponse\"\x9e\x01\n\x1b\x41rchiveEventContractRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12N\n\x12\x65vent_contract_ref\x18\x02 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRefB\x03\xe0\x41\x02\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1c\x41rchiveEventContractResponse\"\x90\x01\n\x1bValidateMaskedFieldsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12@\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFields\x12\x17\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"\x89\x03\n\x1cValidateMaskedFieldsResponse\x12V\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x46.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error\x1a\x90\x02\n\x05\x45rror\x12I\n\x12\x65vent_contract_ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x61\n\x06\x65rrors\x18\x03 \x03(\x0b\x32Q.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldError\x1aH\n\nFieldError\x12\x15\n\rfield_pattern\x18\x01 \x01(\t\x12\x12\n\nfield_type\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"^\n GetEventContractAndSchemaRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.EventContractRef\"\xb2\x01\n!GetEventContractAndSchemaResponse\x12\x42\n\x0e\x65vent_contract\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.EventContract\x12\x33\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.Schema\x12\x14\n\x0c\x63onfluent_id\x18\x03 \x01(\x05\x32\x8a\x0b\n\x15\x45ventContractsService\x12\x93\x01\n\x12ListEventContracts\x12=.strmprivacy.api.event_contracts.v1.ListEventContractsRequest\x1a>.strmprivacy.api.event_contracts.v1.ListEventContractsResponse\x12\x8d\x01\n\x10GetEventContract\x12;.strmprivacy.api.event_contracts.v1.GetEventContractRequest\x1a<.strmprivacy.api.event_contracts.v1.GetEventContractResponse\x12\x96\x01\n\x13\x43reateEventContract\x12>.strmprivacy.api.event_contracts.v1.CreateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.CreateEventContractResponse\x12\x96\x01\n\x13UpdateEventContract\x12>.strmprivacy.api.event_contracts.v1.UpdateEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.UpdateEventContractResponse\x12\x9c\x01\n\x15\x41\x63tivateEventContract\x12@.strmprivacy.api.event_contracts.v1.ActivateEventContractRequest\x1a\x41.strmprivacy.api.event_contracts.v1.ActivateEventContractResponse\x12\x96\x01\n\x13\x44\x65leteEventContract\x12>.strmprivacy.api.event_contracts.v1.DeleteEventContractRequest\x1a?.strmprivacy.api.event_contracts.v1.DeleteEventContractResponse\x12\x99\x01\n\x14\x41rchiveEventContract\x12?.strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest\x1a@.strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse\x12\x99\x01\n\x14ValidateMaskedFields\x12?.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest\x1a@.strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse\x12\xa8\x01\n\x19GetEventContractAndSchema\x12\x44.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest\x1a\x45.strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponseB~\n%io.strmprivacy.api.event_contracts.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contractsb\x06proto3')



_LISTEVENTCONTRACTSREQUEST = DESCRIPTOR.message_types_by_name['ListEventContractsRequest']
_LISTEVENTCONTRACTSRESPONSE = DESCRIPTOR.message_types_by_name['ListEventContractsResponse']
_GETEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['GetEventContractRequest']
_GETEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['GetEventContractResponse']
_CREATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['CreateEventContractRequest']
_CREATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['CreateEventContractResponse']
_UPDATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['UpdateEventContractRequest']
_UPDATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEventContractResponse']
_ACTIVATEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ActivateEventContractRequest']
_ACTIVATEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ActivateEventContractResponse']
_DELETEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['DeleteEventContractRequest']
_DELETEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEventContractResponse']
_ARCHIVEEVENTCONTRACTREQUEST = DESCRIPTOR.message_types_by_name['ArchiveEventContractRequest']
_ARCHIVEEVENTCONTRACTRESPONSE = DESCRIPTOR.message_types_by_name['ArchiveEventContractResponse']
_VALIDATEMASKEDFIELDSREQUEST = DESCRIPTOR.message_types_by_name['ValidateMaskedFieldsRequest']
_VALIDATEMASKEDFIELDSRESPONSE = DESCRIPTOR.message_types_by_name['ValidateMaskedFieldsResponse']
_VALIDATEMASKEDFIELDSRESPONSE_ERROR = _VALIDATEMASKEDFIELDSRESPONSE.nested_types_by_name['Error']
_VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR = _VALIDATEMASKEDFIELDSRESPONSE_ERROR.nested_types_by_name['FieldError']
_GETEVENTCONTRACTANDSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['GetEventContractAndSchemaRequest']
_GETEVENTCONTRACTANDSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['GetEventContractAndSchemaResponse']
ListEventContractsRequest = _reflection.GeneratedProtocolMessageType('ListEventContractsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTCONTRACTSREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ListEventContractsRequest)
  })
_sym_db.RegisterMessage(ListEventContractsRequest)

ListEventContractsResponse = _reflection.GeneratedProtocolMessageType('ListEventContractsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTCONTRACTSRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ListEventContractsResponse)
  })
_sym_db.RegisterMessage(ListEventContractsResponse)

GetEventContractRequest = _reflection.GeneratedProtocolMessageType('GetEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractRequest)
  })
_sym_db.RegisterMessage(GetEventContractRequest)

GetEventContractResponse = _reflection.GeneratedProtocolMessageType('GetEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractResponse)
  })
_sym_db.RegisterMessage(GetEventContractResponse)

CreateEventContractRequest = _reflection.GeneratedProtocolMessageType('CreateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.CreateEventContractRequest)
  })
_sym_db.RegisterMessage(CreateEventContractRequest)

CreateEventContractResponse = _reflection.GeneratedProtocolMessageType('CreateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.CreateEventContractResponse)
  })
_sym_db.RegisterMessage(CreateEventContractResponse)

UpdateEventContractRequest = _reflection.GeneratedProtocolMessageType('UpdateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.UpdateEventContractRequest)
  })
_sym_db.RegisterMessage(UpdateEventContractRequest)

UpdateEventContractResponse = _reflection.GeneratedProtocolMessageType('UpdateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.UpdateEventContractResponse)
  })
_sym_db.RegisterMessage(UpdateEventContractResponse)

ActivateEventContractRequest = _reflection.GeneratedProtocolMessageType('ActivateEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ActivateEventContractRequest)
  })
_sym_db.RegisterMessage(ActivateEventContractRequest)

ActivateEventContractResponse = _reflection.GeneratedProtocolMessageType('ActivateEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ActivateEventContractResponse)
  })
_sym_db.RegisterMessage(ActivateEventContractResponse)

DeleteEventContractRequest = _reflection.GeneratedProtocolMessageType('DeleteEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.DeleteEventContractRequest)
  })
_sym_db.RegisterMessage(DeleteEventContractRequest)

DeleteEventContractResponse = _reflection.GeneratedProtocolMessageType('DeleteEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.DeleteEventContractResponse)
  })
_sym_db.RegisterMessage(DeleteEventContractResponse)

ArchiveEventContractRequest = _reflection.GeneratedProtocolMessageType('ArchiveEventContractRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEEVENTCONTRACTREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ArchiveEventContractRequest)
  })
_sym_db.RegisterMessage(ArchiveEventContractRequest)

ArchiveEventContractResponse = _reflection.GeneratedProtocolMessageType('ArchiveEventContractResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARCHIVEEVENTCONTRACTRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ArchiveEventContractResponse)
  })
_sym_db.RegisterMessage(ArchiveEventContractResponse)

ValidateMaskedFieldsRequest = _reflection.GeneratedProtocolMessageType('ValidateMaskedFieldsRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMASKEDFIELDSREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsRequest)
  })
_sym_db.RegisterMessage(ValidateMaskedFieldsRequest)

ValidateMaskedFieldsResponse = _reflection.GeneratedProtocolMessageType('ValidateMaskedFieldsResponse', (_message.Message,), {

  'Error' : _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {

    'FieldError' : _reflection.GeneratedProtocolMessageType('FieldError', (_message.Message,), {
      'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR,
      '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
      # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error.FieldError)
      })
    ,
    'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE_ERROR,
    '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
    # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse.Error)
    })
  ,
  'DESCRIPTOR' : _VALIDATEMASKEDFIELDSRESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.ValidateMaskedFieldsResponse)
  })
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse)
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse.Error)
_sym_db.RegisterMessage(ValidateMaskedFieldsResponse.Error.FieldError)

GetEventContractAndSchemaRequest = _reflection.GeneratedProtocolMessageType('GetEventContractAndSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTANDSCHEMAREQUEST,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaRequest)
  })
_sym_db.RegisterMessage(GetEventContractAndSchemaRequest)

GetEventContractAndSchemaResponse = _reflection.GeneratedProtocolMessageType('GetEventContractAndSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEVENTCONTRACTANDSCHEMARESPONSE,
  '__module__' : 'strmprivacy.api.event_contracts.v1.event_contracts_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.event_contracts.v1.GetEventContractAndSchemaResponse)
  })
_sym_db.RegisterMessage(GetEventContractAndSchemaResponse)

_EVENTCONTRACTSSERVICE = DESCRIPTOR.services_by_name['EventContractsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.event_contracts.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/event_contracts/v1;event_contracts'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._options = None
  _LISTEVENTCONTRACTSREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['event_contract']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _UPDATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEEVENTCONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['event_contract_ref']._serialized_options = b'\340A\002'
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVEEVENTCONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._options = None
  _VALIDATEMASKEDFIELDSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _LISTEVENTCONTRACTSREQUEST._serialized_start=214
  _LISTEVENTCONTRACTSREQUEST._serialized_end=574
  _LISTEVENTCONTRACTSRESPONSE._serialized_start=576
  _LISTEVENTCONTRACTSRESPONSE._serialized_end=673
  _GETEVENTCONTRACTREQUEST._serialized_start=675
  _GETEVENTCONTRACTREQUEST._serialized_end=784
  _GETEVENTCONTRACTRESPONSE._serialized_start=786
  _GETEVENTCONTRACTRESPONSE._serialized_end=903
  _CREATEEVENTCONTRACTREQUEST._serialized_start=906
  _CREATEEVENTCONTRACTREQUEST._serialized_end=1046
  _CREATEEVENTCONTRACTRESPONSE._serialized_start=1048
  _CREATEEVENTCONTRACTRESPONSE._serialized_end=1168
  _UPDATEEVENTCONTRACTREQUEST._serialized_start=1171
  _UPDATEEVENTCONTRACTREQUEST._serialized_end=1398
  _UPDATEEVENTCONTRACTRESPONSE._serialized_start=1400
  _UPDATEEVENTCONTRACTRESPONSE._serialized_end=1520
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_start=1523
  _ACTIVATEEVENTCONTRACTREQUEST._serialized_end=1682
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_start=1684
  _ACTIVATEEVENTCONTRACTRESPONSE._serialized_end=1715
  _DELETEEVENTCONTRACTREQUEST._serialized_start=1718
  _DELETEEVENTCONTRACTREQUEST._serialized_end=1875
  _DELETEEVENTCONTRACTRESPONSE._serialized_start=1877
  _DELETEEVENTCONTRACTRESPONSE._serialized_end=1906
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_start=1909
  _ARCHIVEEVENTCONTRACTREQUEST._serialized_end=2067
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_start=2069
  _ARCHIVEEVENTCONTRACTRESPONSE._serialized_end=2099
  _VALIDATEMASKEDFIELDSREQUEST._serialized_start=2102
  _VALIDATEMASKEDFIELDSREQUEST._serialized_end=2246
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_start=2249
  _VALIDATEMASKEDFIELDSRESPONSE._serialized_end=2642
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_start=2370
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR._serialized_end=2642
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=2570
  _VALIDATEMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=2642
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_start=2644
  _GETEVENTCONTRACTANDSCHEMAREQUEST._serialized_end=2738
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_start=2741
  _GETEVENTCONTRACTANDSCHEMARESPONSE._serialized_end=2919
  _EVENTCONTRACTSSERVICE._serialized_start=2922
  _EVENTCONTRACTSSERVICE._serialized_end=4340
# @@protoc_insertion_point(module_scope)
