# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_connectors/v1/data_connectors_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/data_connectors/v1/data_connectors_v1.proto\x12\"strmprivacy.api.data_connectors.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"|\n\x19ListDataConnectorsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08\x12\x17\n\nproject_id\x18\x04 \x01(\tB\x03\xe0\x41\x02\"a\n\x1aListDataConnectorsResponse\x12\x43\n\x0f\x64\x61ta_connectors\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector\"p\n\x1a\x44\x65leteDataConnectorRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\"\x1d\n\x1b\x44\x65leteDataConnectorResponse\"e\n\x1a\x43reateDataConnectorRequest\x12G\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnectorB\x03\xe0\x41\x02\"a\n\x1b\x43reateDataConnectorResponse\x12\x42\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector\"\x8a\x01\n\x17GetDataConnectorRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.DataConnectorRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08\"^\n\x18GetDataConnectorResponse\x12\x42\n\x0e\x64\x61ta_connector\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.DataConnector2\xef\x04\n\x15\x44\x61taConnectorsService\x12\x93\x01\n\x12ListDataConnectors\x12=.strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest\x1a>.strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse\x12\x8d\x01\n\x10GetDataConnector\x12;.strmprivacy.api.data_connectors.v1.GetDataConnectorRequest\x1a<.strmprivacy.api.data_connectors.v1.GetDataConnectorResponse\x12\x96\x01\n\x13\x44\x65leteDataConnector\x12>.strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse\x12\x96\x01\n\x13\x43reateDataConnector\x12>.strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest\x1a?.strmprivacy.api.data_connectors.v1.CreateDataConnectorResponseB~\n%io.strmprivacy.api.data_connectors.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectorsb\x06proto3')



_LISTDATACONNECTORSREQUEST = DESCRIPTOR.message_types_by_name['ListDataConnectorsRequest']
_LISTDATACONNECTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListDataConnectorsResponse']
_DELETEDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataConnectorRequest']
_DELETEDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataConnectorResponse']
_CREATEDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['CreateDataConnectorRequest']
_CREATEDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataConnectorResponse']
_GETDATACONNECTORREQUEST = DESCRIPTOR.message_types_by_name['GetDataConnectorRequest']
_GETDATACONNECTORRESPONSE = DESCRIPTOR.message_types_by_name['GetDataConnectorResponse']
ListDataConnectorsRequest = _reflection.GeneratedProtocolMessageType('ListDataConnectorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONNECTORSREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.ListDataConnectorsRequest)
  })
_sym_db.RegisterMessage(ListDataConnectorsRequest)

ListDataConnectorsResponse = _reflection.GeneratedProtocolMessageType('ListDataConnectorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATACONNECTORSRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.ListDataConnectorsResponse)
  })
_sym_db.RegisterMessage(ListDataConnectorsResponse)

DeleteDataConnectorRequest = _reflection.GeneratedProtocolMessageType('DeleteDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.DeleteDataConnectorRequest)
  })
_sym_db.RegisterMessage(DeleteDataConnectorRequest)

DeleteDataConnectorResponse = _reflection.GeneratedProtocolMessageType('DeleteDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.DeleteDataConnectorResponse)
  })
_sym_db.RegisterMessage(DeleteDataConnectorResponse)

CreateDataConnectorRequest = _reflection.GeneratedProtocolMessageType('CreateDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.CreateDataConnectorRequest)
  })
_sym_db.RegisterMessage(CreateDataConnectorRequest)

CreateDataConnectorResponse = _reflection.GeneratedProtocolMessageType('CreateDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.CreateDataConnectorResponse)
  })
_sym_db.RegisterMessage(CreateDataConnectorResponse)

GetDataConnectorRequest = _reflection.GeneratedProtocolMessageType('GetDataConnectorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONNECTORREQUEST,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.GetDataConnectorRequest)
  })
_sym_db.RegisterMessage(GetDataConnectorRequest)

GetDataConnectorResponse = _reflection.GeneratedProtocolMessageType('GetDataConnectorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACONNECTORRESPONSE,
  '__module__' : 'strmprivacy.api.data_connectors.v1.data_connectors_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.data_connectors.v1.GetDataConnectorResponse)
  })
_sym_db.RegisterMessage(GetDataConnectorResponse)

_DATACONNECTORSSERVICE = DESCRIPTOR.services_by_name['DataConnectorsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.data_connectors.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/data_connectors/v1;data_connectors'
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONNECTORSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _DELETEDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._options = None
  _CREATEDATACONNECTORREQUEST.fields_by_name['data_connector']._serialized_options = b'\340A\002'
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._options = None
  _GETDATACONNECTORREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTDATACONNECTORSREQUEST._serialized_start=179
  _LISTDATACONNECTORSREQUEST._serialized_end=303
  _LISTDATACONNECTORSRESPONSE._serialized_start=305
  _LISTDATACONNECTORSRESPONSE._serialized_end=402
  _DELETEDATACONNECTORREQUEST._serialized_start=404
  _DELETEDATACONNECTORREQUEST._serialized_end=516
  _DELETEDATACONNECTORRESPONSE._serialized_start=518
  _DELETEDATACONNECTORRESPONSE._serialized_end=547
  _CREATEDATACONNECTORREQUEST._serialized_start=549
  _CREATEDATACONNECTORREQUEST._serialized_end=650
  _CREATEDATACONNECTORRESPONSE._serialized_start=652
  _CREATEDATACONNECTORRESPONSE._serialized_end=749
  _GETDATACONNECTORREQUEST._serialized_start=752
  _GETDATACONNECTORREQUEST._serialized_end=890
  _GETDATACONNECTORRESPONSE._serialized_start=892
  _GETDATACONNECTORRESPONSE._serialized_end=986
  _DATACONNECTORSSERVICE._serialized_start=989
  _DATACONNECTORSSERVICE._serialized_end=1612
# @@protoc_insertion_point(module_scope)
