# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8strmprivacy/api/agents/v1/batch_exporters_agent_v1.proto\x12\x19strmprivacy.api.agents.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"!\n\x1fGetDesiredBatchExportersRequest\"i\n GetDesiredBatchExportersResponse\x12\x45\n\texporters\x18\x01 \x03(\x0b\x32\x32.strmprivacy.api.entities.v1.ExtendedBatchExporter2\xb2\x01\n\x1a\x42\x61tchExportersAgentService\x12\x93\x01\n\x18GetDesiredBatchExporters\x12:.strmprivacy.api.agents.v1.GetDesiredBatchExportersRequest\x1a;.strmprivacy.api.agents.v1.GetDesiredBatchExportersResponseBc\n\x1cio.strmprivacy.api.agents.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agentsb\x06proto3')



_GETDESIREDBATCHEXPORTERSREQUEST = DESCRIPTOR.message_types_by_name['GetDesiredBatchExportersRequest']
_GETDESIREDBATCHEXPORTERSRESPONSE = DESCRIPTOR.message_types_by_name['GetDesiredBatchExportersResponse']
GetDesiredBatchExportersRequest = _reflection.GeneratedProtocolMessageType('GetDesiredBatchExportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDBATCHEXPORTERSREQUEST,
  '__module__' : 'strmprivacy.api.agents.v1.batch_exporters_agent_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.agents.v1.GetDesiredBatchExportersRequest)
  })
_sym_db.RegisterMessage(GetDesiredBatchExportersRequest)

GetDesiredBatchExportersResponse = _reflection.GeneratedProtocolMessageType('GetDesiredBatchExportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDBATCHEXPORTERSRESPONSE,
  '__module__' : 'strmprivacy.api.agents.v1.batch_exporters_agent_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.agents.v1.GetDesiredBatchExportersResponse)
  })
_sym_db.RegisterMessage(GetDesiredBatchExportersResponse)

_BATCHEXPORTERSAGENTSERVICE = DESCRIPTOR.services_by_name['BatchExportersAgentService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.agents.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v2/api/agents/v1;agents'
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_start=134
  _GETDESIREDBATCHEXPORTERSREQUEST._serialized_end=167
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_start=169
  _GETDESIREDBATCHEXPORTERSRESPONSE._serialized_end=274
  _BATCHEXPORTERSAGENTSERVICE._serialized_start=277
  _BATCHEXPORTERSAGENTSERVICE._serialized_end=455
# @@protoc_insertion_point(module_scope)
