# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installed_components_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>strmprivacy/api/installations/v1/installed_components_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"\x98\x02\n$UpdateInstalledComponentStateRequest\x12U\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\x12\x18\n\x0binstance_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x61\n\x19installed_component_state\x18\x03 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateB\x03\xe0\x41\x02\x12\x1c\n\x0finstallation_id\x18\x04 \x01(\tB\x03\xe0\x41\x02\"\'\n%UpdateInstalledComponentStateResponse\"\x9d\x01\n\x1cGetInstalledComponentRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12_\n\x18installed_component_type\x18\x02 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x03\xe0\x41\x02\"r\n\x1dGetInstalledComponentResponse\x12Q\n\x13installed_component\x18\x01 \x01(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponent\">\n\x1eListInstalledComponentsRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"u\n\x1fListInstalledComponentsResponse\x12R\n\x14installed_components\x18\x01 \x03(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponent\"K\n+ListInstalledComponentsCurrentStatesRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x8f\x01\n,ListInstalledComponentsCurrentStatesResponse\x12_\n\x14installed_components\x18\x01 \x03(\x0b\x32\x41.strmprivacy.api.installations.v1.InstalledComponentsCurrentState2\xd3\x05\n\x1aInstalledComponentsService\x12\xb0\x01\n\x1dUpdateInstalledComponentState\x12\x46.strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest\x1aG.strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse\x12\x98\x01\n\x15GetInstalledComponent\x12>.strmprivacy.api.installations.v1.GetInstalledComponentRequest\x1a?.strmprivacy.api.installations.v1.GetInstalledComponentResponse\x12\x9e\x01\n\x17ListInstalledComponents\x12@.strmprivacy.api.installations.v1.ListInstalledComponentsRequest\x1a\x41.strmprivacy.api.installations.v1.ListInstalledComponentsResponse\x12\xc5\x01\n$ListInstalledComponentsCurrentStates\x12M.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest\x1aN.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')



_UPDATEINSTALLEDCOMPONENTSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateInstalledComponentStateRequest']
_UPDATEINSTALLEDCOMPONENTSTATERESPONSE = DESCRIPTOR.message_types_by_name['UpdateInstalledComponentStateResponse']
_GETINSTALLEDCOMPONENTREQUEST = DESCRIPTOR.message_types_by_name['GetInstalledComponentRequest']
_GETINSTALLEDCOMPONENTRESPONSE = DESCRIPTOR.message_types_by_name['GetInstalledComponentResponse']
_LISTINSTALLEDCOMPONENTSREQUEST = DESCRIPTOR.message_types_by_name['ListInstalledComponentsRequest']
_LISTINSTALLEDCOMPONENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListInstalledComponentsResponse']
_LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST = DESCRIPTOR.message_types_by_name['ListInstalledComponentsCurrentStatesRequest']
_LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE = DESCRIPTOR.message_types_by_name['ListInstalledComponentsCurrentStatesResponse']
UpdateInstalledComponentStateRequest = _reflection.GeneratedProtocolMessageType('UpdateInstalledComponentStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTALLEDCOMPONENTSTATEREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest)
  })
_sym_db.RegisterMessage(UpdateInstalledComponentStateRequest)

UpdateInstalledComponentStateResponse = _reflection.GeneratedProtocolMessageType('UpdateInstalledComponentStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTALLEDCOMPONENTSTATERESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse)
  })
_sym_db.RegisterMessage(UpdateInstalledComponentStateResponse)

GetInstalledComponentRequest = _reflection.GeneratedProtocolMessageType('GetInstalledComponentRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLEDCOMPONENTREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstalledComponentRequest)
  })
_sym_db.RegisterMessage(GetInstalledComponentRequest)

GetInstalledComponentResponse = _reflection.GeneratedProtocolMessageType('GetInstalledComponentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLEDCOMPONENTRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstalledComponentResponse)
  })
_sym_db.RegisterMessage(GetInstalledComponentResponse)

ListInstalledComponentsRequest = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsRequest)
  })
_sym_db.RegisterMessage(ListInstalledComponentsRequest)

ListInstalledComponentsResponse = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsResponse)
  })
_sym_db.RegisterMessage(ListInstalledComponentsResponse)

ListInstalledComponentsCurrentStatesRequest = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsCurrentStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest)
  })
_sym_db.RegisterMessage(ListInstalledComponentsCurrentStatesRequest)

ListInstalledComponentsCurrentStatesResponse = _reflection.GeneratedProtocolMessageType('ListInstalledComponentsCurrentStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installed_components_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponse)
  })
_sym_db.RegisterMessage(ListInstalledComponentsCurrentStatesResponse)

_INSTALLEDCOMPONENTSSERVICE = DESCRIPTOR.services_by_name['InstalledComponentsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_start=186
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_end=466
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_start=468
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_end=507
  _GETINSTALLEDCOMPONENTREQUEST._serialized_start=510
  _GETINSTALLEDCOMPONENTREQUEST._serialized_end=667
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_start=669
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_end=783
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_start=785
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_end=847
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_start=849
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_end=966
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_start=968
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_end=1043
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_start=1046
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_end=1189
  _INSTALLEDCOMPONENTSSERVICE._serialized_start=1192
  _INSTALLEDCOMPONENTSSERVICE._serialized_end=1915
# @@protoc_insertion_point(module_scope)
