# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_users/v1/kafka_users_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/kafka_users/v1/kafka_users_v1.proto\x12\x1estrmprivacy.api.kafka_users.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"X\n\x15ListKafkaUsersRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x03\xe0\x41\x02\"U\n\x16ListKafkaUsersResponse\x12;\n\x0bkafka_users\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"U\n\x16\x44\x65leteKafkaUserRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02\"\x19\n\x17\x44\x65leteKafkaUserResponse\"T\n\x16\x43reateKafkaUserRequest\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"U\n\x17\x43reateKafkaUserResponse\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser\"R\n\x13GetKafkaUserRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x03\xe0\x41\x02\"R\n\x14GetKafkaUserResponse\x12:\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUser2\x99\x04\n\x11KafkaUsersService\x12\x7f\n\x0eListKafkaUsers\x12\x35.strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest\x1a\x36.strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse\x12y\n\x0cGetKafkaUser\x12\x33.strmprivacy.api.kafka_users.v1.GetKafkaUserRequest\x1a\x34.strmprivacy.api.kafka_users.v1.GetKafkaUserResponse\x12\x82\x01\n\x0f\x44\x65leteKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse\x12\x82\x01\n\x0f\x43reateKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.CreateKafkaUserResponseBr\n!io.strmprivacy.api.kafka_users.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_usersb\x06proto3')



_LISTKAFKAUSERSREQUEST = DESCRIPTOR.message_types_by_name['ListKafkaUsersRequest']
_LISTKAFKAUSERSRESPONSE = DESCRIPTOR.message_types_by_name['ListKafkaUsersResponse']
_DELETEKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['DeleteKafkaUserRequest']
_DELETEKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteKafkaUserResponse']
_CREATEKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['CreateKafkaUserRequest']
_CREATEKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['CreateKafkaUserResponse']
_GETKAFKAUSERREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaUserRequest']
_GETKAFKAUSERRESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaUserResponse']
ListKafkaUsersRequest = _reflection.GeneratedProtocolMessageType('ListKafkaUsersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAUSERSREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest)
  })
_sym_db.RegisterMessage(ListKafkaUsersRequest)

ListKafkaUsersResponse = _reflection.GeneratedProtocolMessageType('ListKafkaUsersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTKAFKAUSERSRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse)
  })
_sym_db.RegisterMessage(ListKafkaUsersResponse)

DeleteKafkaUserRequest = _reflection.GeneratedProtocolMessageType('DeleteKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest)
  })
_sym_db.RegisterMessage(DeleteKafkaUserRequest)

DeleteKafkaUserResponse = _reflection.GeneratedProtocolMessageType('DeleteKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse)
  })
_sym_db.RegisterMessage(DeleteKafkaUserResponse)

CreateKafkaUserRequest = _reflection.GeneratedProtocolMessageType('CreateKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest)
  })
_sym_db.RegisterMessage(CreateKafkaUserRequest)

CreateKafkaUserResponse = _reflection.GeneratedProtocolMessageType('CreateKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.CreateKafkaUserResponse)
  })
_sym_db.RegisterMessage(CreateKafkaUserResponse)

GetKafkaUserRequest = _reflection.GeneratedProtocolMessageType('GetKafkaUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAUSERREQUEST,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.GetKafkaUserRequest)
  })
_sym_db.RegisterMessage(GetKafkaUserRequest)

GetKafkaUserResponse = _reflection.GeneratedProtocolMessageType('GetKafkaUserResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAUSERRESPONSE,
  '__module__' : 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.kafka_users.v1.GetKafkaUserResponse)
  })
_sym_db.RegisterMessage(GetKafkaUserResponse)

_KAFKAUSERSSERVICE = DESCRIPTOR.services_by_name['KafkaUsersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.kafka_users.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_users'
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._options = None
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTKAFKAUSERSREQUEST._serialized_start=167
  _LISTKAFKAUSERSREQUEST._serialized_end=255
  _LISTKAFKAUSERSRESPONSE._serialized_start=257
  _LISTKAFKAUSERSRESPONSE._serialized_end=342
  _DELETEKAFKAUSERREQUEST._serialized_start=344
  _DELETEKAFKAUSERREQUEST._serialized_end=429
  _DELETEKAFKAUSERRESPONSE._serialized_start=431
  _DELETEKAFKAUSERRESPONSE._serialized_end=456
  _CREATEKAFKAUSERREQUEST._serialized_start=458
  _CREATEKAFKAUSERREQUEST._serialized_end=542
  _CREATEKAFKAUSERRESPONSE._serialized_start=544
  _CREATEKAFKAUSERRESPONSE._serialized_end=629
  _GETKAFKAUSERREQUEST._serialized_start=631
  _GETKAFKAUSERREQUEST._serialized_end=713
  _GETKAFKAUSERRESPONSE._serialized_start=715
  _GETKAFKAUSERRESPONSE._serialized_end=797
  _KAFKAUSERSSERVICE._serialized_start=800
  _KAFKAUSERSSERVICE._serialized_end=1337
# @@protoc_insertion_point(module_scope)
