# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/batch_exporters/v1/batch_exporters_v1.proto\x12\"strmprivacy.api.batch_exporters.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"L\n\x19ListBatchExportersRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"a\n\x1aListBatchExportersResponse\x12\x43\n\x0f\x62\x61tch_exporters\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"]\n\x1a\x44\x65leteBatchExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02\"\x1d\n\x1b\x44\x65leteBatchExporterResponse\"`\n\x1a\x43reateBatchExporterRequest\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"a\n\x1b\x43reateBatchExporterResponse\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter\"Z\n\x17GetBatchExporterRequest\x12?\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.BatchExporterRefB\x03\xe0\x41\x02\"^\n\x18GetBatchExporterResponse\x12\x42\n\x0e\x62\x61tch_exporter\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchExporter2\xef\x04\n\x15\x42\x61tchExportersService\x12\x93\x01\n\x12ListBatchExporters\x12=.strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest\x1a>.strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse\x12\x8d\x01\n\x10GetBatchExporter\x12;.strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest\x1a<.strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse\x12\x96\x01\n\x13\x44\x65leteBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse\x12\x96\x01\n\x13\x43reateBatchExporter\x12>.strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest\x1a?.strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponseB~\n%io.strmprivacy.api.batch_exporters.v1P\x01ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exportersb\x06proto3')



_LISTBATCHEXPORTERSREQUEST = DESCRIPTOR.message_types_by_name['ListBatchExportersRequest']
_LISTBATCHEXPORTERSRESPONSE = DESCRIPTOR.message_types_by_name['ListBatchExportersResponse']
_DELETEBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['DeleteBatchExporterRequest']
_DELETEBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBatchExporterResponse']
_CREATEBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['CreateBatchExporterRequest']
_CREATEBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['CreateBatchExporterResponse']
_GETBATCHEXPORTERREQUEST = DESCRIPTOR.message_types_by_name['GetBatchExporterRequest']
_GETBATCHEXPORTERRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchExporterResponse']
ListBatchExportersRequest = _reflection.GeneratedProtocolMessageType('ListBatchExportersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHEXPORTERSREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.ListBatchExportersRequest)
  })
_sym_db.RegisterMessage(ListBatchExportersRequest)

ListBatchExportersResponse = _reflection.GeneratedProtocolMessageType('ListBatchExportersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHEXPORTERSRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.ListBatchExportersResponse)
  })
_sym_db.RegisterMessage(ListBatchExportersResponse)

DeleteBatchExporterRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.DeleteBatchExporterRequest)
  })
_sym_db.RegisterMessage(DeleteBatchExporterRequest)

DeleteBatchExporterResponse = _reflection.GeneratedProtocolMessageType('DeleteBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.DeleteBatchExporterResponse)
  })
_sym_db.RegisterMessage(DeleteBatchExporterResponse)

CreateBatchExporterRequest = _reflection.GeneratedProtocolMessageType('CreateBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.CreateBatchExporterRequest)
  })
_sym_db.RegisterMessage(CreateBatchExporterRequest)

CreateBatchExporterResponse = _reflection.GeneratedProtocolMessageType('CreateBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.CreateBatchExporterResponse)
  })
_sym_db.RegisterMessage(CreateBatchExporterResponse)

GetBatchExporterRequest = _reflection.GeneratedProtocolMessageType('GetBatchExporterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERREQUEST,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.GetBatchExporterRequest)
  })
_sym_db.RegisterMessage(GetBatchExporterRequest)

GetBatchExporterResponse = _reflection.GeneratedProtocolMessageType('GetBatchExporterResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERRESPONSE,
  '__module__' : 'strmprivacy.api.batch_exporters.v1.batch_exporters_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_exporters.v1.GetBatchExporterResponse)
  })
_sym_db.RegisterMessage(GetBatchExporterResponse)

_BATCHEXPORTERSSERVICE = DESCRIPTOR.services_by_name['BatchExportersService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.batch_exporters.v1P\001ZSgithub.com/strmprivacy/api-definitions-go/v2/api/batch_exporters/v1;batch_exporters'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHEXPORTERSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._options = None
  _GETBATCHEXPORTERREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _LISTBATCHEXPORTERSREQUEST._serialized_start=179
  _LISTBATCHEXPORTERSREQUEST._serialized_end=255
  _LISTBATCHEXPORTERSRESPONSE._serialized_start=257
  _LISTBATCHEXPORTERSRESPONSE._serialized_end=354
  _DELETEBATCHEXPORTERREQUEST._serialized_start=356
  _DELETEBATCHEXPORTERREQUEST._serialized_end=449
  _DELETEBATCHEXPORTERRESPONSE._serialized_start=451
  _DELETEBATCHEXPORTERRESPONSE._serialized_end=480
  _CREATEBATCHEXPORTERREQUEST._serialized_start=482
  _CREATEBATCHEXPORTERREQUEST._serialized_end=578
  _CREATEBATCHEXPORTERRESPONSE._serialized_start=580
  _CREATEBATCHEXPORTERRESPONSE._serialized_end=677
  _GETBATCHEXPORTERREQUEST._serialized_start=679
  _GETBATCHEXPORTERREQUEST._serialized_end=769
  _GETBATCHEXPORTERRESPONSE._serialized_start=771
  _GETBATCHEXPORTERRESPONSE._serialized_end=865
  _BATCHEXPORTERSSERVICE._serialized_start=868
  _BATCHEXPORTERSSERVICE._serialized_end=1491
# @@protoc_insertion_point(module_scope)
