# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/sinks/v1/sinks_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/sinks/v1/sinks_v1.proto\x12\x18strmprivacy.api.sinks.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"Z\n\x10ListSinksRequest\x12\x12\n\nbilling_id\x18\x01 \x01(\t\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08:\x02\x18\x01\"M\n\x11ListSinksResponse\x12\x34\n\x05sinks\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.SinkTree:\x02\x18\x01\"b\n\x11\x44\x65leteSinkRequest\x12\x36\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08:\x02\x18\x01\"\x18\n\x12\x44\x65leteSinkResponse:\x02\x18\x01\"j\n\x11\x43reateSinkRequest\x12\x34\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02\x12\x1b\n\x13include_credentials\x18\x02 \x01(\x08:\x02\x18\x01\"I\n\x12\x43reateSinkResponse\x12/\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.Sink:\x02\x18\x01\"|\n\x0eGetSinkRequest\x12\x36\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02\x12\x11\n\trecursive\x18\x02 \x01(\x08\x12\x1b\n\x13include_credentials\x18\x03 \x01(\x08:\x02\x18\x01\"O\n\x0fGetSinkResponse\x12\x38\n\tsink_tree\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.SinkTree:\x02\x18\x01\x32\xab\x03\n\x0cSinksService\x12\x64\n\tListSinks\x12*.strmprivacy.api.sinks.v1.ListSinksRequest\x1a+.strmprivacy.api.sinks.v1.ListSinksResponse\x12^\n\x07GetSink\x12(.strmprivacy.api.sinks.v1.GetSinkRequest\x1a).strmprivacy.api.sinks.v1.GetSinkResponse\x12g\n\nDeleteSink\x12+.strmprivacy.api.sinks.v1.DeleteSinkRequest\x1a,.strmprivacy.api.sinks.v1.DeleteSinkResponse\x12g\n\nCreateSink\x12+.strmprivacy.api.sinks.v1.CreateSinkRequest\x1a,.strmprivacy.api.sinks.v1.CreateSinkResponse\x1a\x03\x88\x02\x01\x42`\n\x1bio.strmprivacy.api.sinks.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinksb\x06proto3')



_LISTSINKSREQUEST = DESCRIPTOR.message_types_by_name['ListSinksRequest']
_LISTSINKSRESPONSE = DESCRIPTOR.message_types_by_name['ListSinksResponse']
_DELETESINKREQUEST = DESCRIPTOR.message_types_by_name['DeleteSinkRequest']
_DELETESINKRESPONSE = DESCRIPTOR.message_types_by_name['DeleteSinkResponse']
_CREATESINKREQUEST = DESCRIPTOR.message_types_by_name['CreateSinkRequest']
_CREATESINKRESPONSE = DESCRIPTOR.message_types_by_name['CreateSinkResponse']
_GETSINKREQUEST = DESCRIPTOR.message_types_by_name['GetSinkRequest']
_GETSINKRESPONSE = DESCRIPTOR.message_types_by_name['GetSinkResponse']
ListSinksRequest = _reflection.GeneratedProtocolMessageType('ListSinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.ListSinksRequest)
  })
_sym_db.RegisterMessage(ListSinksRequest)

ListSinksResponse = _reflection.GeneratedProtocolMessageType('ListSinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSINKSRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.ListSinksResponse)
  })
_sym_db.RegisterMessage(ListSinksResponse)

DeleteSinkRequest = _reflection.GeneratedProtocolMessageType('DeleteSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.DeleteSinkRequest)
  })
_sym_db.RegisterMessage(DeleteSinkRequest)

DeleteSinkResponse = _reflection.GeneratedProtocolMessageType('DeleteSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.DeleteSinkResponse)
  })
_sym_db.RegisterMessage(DeleteSinkResponse)

CreateSinkRequest = _reflection.GeneratedProtocolMessageType('CreateSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.CreateSinkRequest)
  })
_sym_db.RegisterMessage(CreateSinkRequest)

CreateSinkResponse = _reflection.GeneratedProtocolMessageType('CreateSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.CreateSinkResponse)
  })
_sym_db.RegisterMessage(CreateSinkResponse)

GetSinkRequest = _reflection.GeneratedProtocolMessageType('GetSinkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKREQUEST,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.GetSinkRequest)
  })
_sym_db.RegisterMessage(GetSinkRequest)

GetSinkResponse = _reflection.GeneratedProtocolMessageType('GetSinkResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSINKRESPONSE,
  '__module__' : 'strmprivacy.api.sinks.v1.sinks_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.sinks.v1.GetSinkResponse)
  })
_sym_db.RegisterMessage(GetSinkResponse)

_SINKSSERVICE = DESCRIPTOR.services_by_name['SinksService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.sinks.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinks'
  _LISTSINKSREQUEST._options = None
  _LISTSINKSREQUEST._serialized_options = b'\030\001'
  _LISTSINKSRESPONSE._options = None
  _LISTSINKSRESPONSE._serialized_options = b'\030\001'
  _DELETESINKREQUEST.fields_by_name['ref']._options = None
  _DELETESINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETESINKREQUEST._options = None
  _DELETESINKREQUEST._serialized_options = b'\030\001'
  _DELETESINKRESPONSE._options = None
  _DELETESINKRESPONSE._serialized_options = b'\030\001'
  _CREATESINKREQUEST.fields_by_name['sink']._options = None
  _CREATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\340A\002'
  _CREATESINKREQUEST._options = None
  _CREATESINKREQUEST._serialized_options = b'\030\001'
  _CREATESINKRESPONSE._options = None
  _CREATESINKRESPONSE._serialized_options = b'\030\001'
  _GETSINKREQUEST.fields_by_name['ref']._options = None
  _GETSINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETSINKREQUEST._options = None
  _GETSINKREQUEST._serialized_options = b'\030\001'
  _GETSINKRESPONSE._options = None
  _GETSINKRESPONSE._serialized_options = b'\030\001'
  _SINKSSERVICE._options = None
  _SINKSSERVICE._serialized_options = b'\210\002\001'
  _LISTSINKSREQUEST._serialized_start=149
  _LISTSINKSREQUEST._serialized_end=239
  _LISTSINKSRESPONSE._serialized_start=241
  _LISTSINKSRESPONSE._serialized_end=318
  _DELETESINKREQUEST._serialized_start=320
  _DELETESINKREQUEST._serialized_end=418
  _DELETESINKRESPONSE._serialized_start=420
  _DELETESINKRESPONSE._serialized_end=444
  _CREATESINKREQUEST._serialized_start=446
  _CREATESINKREQUEST._serialized_end=552
  _CREATESINKRESPONSE._serialized_start=554
  _CREATESINKRESPONSE._serialized_end=627
  _GETSINKREQUEST._serialized_start=629
  _GETSINKREQUEST._serialized_end=753
  _GETSINKRESPONSE._serialized_start=755
  _GETSINKRESPONSE._serialized_end=834
  _SINKSSERVICE._serialized_start=837
  _SINKSSERVICE._serialized_end=1264
# @@protoc_insertion_point(module_scope)
