# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto\x12\x1dstrmprivacy.api.batch_jobs.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"P\n\x12GetBatchJobRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\"T\n\x13GetBatchJobResponse\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"G\n\x14ListBatchJobsRequest\x12\x16\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x17\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\"R\n\x15ListBatchJobsResponse\x12\x39\n\nbatch_jobs\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJob\"V\n\x15\x43reateBatchJobRequest\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"W\n\x16\x43reateBatchJobResponse\x12=\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x03\xe0\x41\x02\"S\n\x15\x44\x65leteBatchJobRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\"\x18\n\x16\x44\x65leteBatchJobResponse\"\xa2\x01\n\x1aUpdateBatchJobStateRequest\x12:\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x03\xe0\x41\x02\x12H\n\x0f\x62\x61tch_job_state\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x03\xe0\x41\x02\"\x1d\n\x1bUpdateBatchJobStateResponse2\x91\x05\n\x10\x42\x61tchJobsService\x12t\n\x0bGetBatchJob\x12\x31.strmprivacy.api.batch_jobs.v1.GetBatchJobRequest\x1a\x32.strmprivacy.api.batch_jobs.v1.GetBatchJobResponse\x12z\n\rListBatchJobs\x12\x33.strmprivacy.api.batch_jobs.v1.ListBatchJobsRequest\x1a\x34.strmprivacy.api.batch_jobs.v1.ListBatchJobsResponse\x12}\n\x0e\x43reateBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.CreateBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.CreateBatchJobResponse\x12}\n\x0e\x44\x65leteBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.DeleteBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.DeleteBatchJobResponse\x12\x8c\x01\n\x13UpdateBatchJobState\x12\x39.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateRequest\x1a:.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateResponseBo\n io.strmprivacy.api.batch_jobs.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobsb\x06proto3')



_GETBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobRequest']
_GETBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobResponse']
_LISTBATCHJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListBatchJobsRequest']
_LISTBATCHJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListBatchJobsResponse']
_CREATEBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['CreateBatchJobRequest']
_CREATEBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['CreateBatchJobResponse']
_DELETEBATCHJOBREQUEST = DESCRIPTOR.message_types_by_name['DeleteBatchJobRequest']
_DELETEBATCHJOBRESPONSE = DESCRIPTOR.message_types_by_name['DeleteBatchJobResponse']
_UPDATEBATCHJOBSTATEREQUEST = DESCRIPTOR.message_types_by_name['UpdateBatchJobStateRequest']
_UPDATEBATCHJOBSTATERESPONSE = DESCRIPTOR.message_types_by_name['UpdateBatchJobStateResponse']
GetBatchJobRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.GetBatchJobRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRequest)

GetBatchJobResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.GetBatchJobResponse)
  })
_sym_db.RegisterMessage(GetBatchJobResponse)

ListBatchJobsRequest = _reflection.GeneratedProtocolMessageType('ListBatchJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.ListBatchJobsRequest)
  })
_sym_db.RegisterMessage(ListBatchJobsRequest)

ListBatchJobsResponse = _reflection.GeneratedProtocolMessageType('ListBatchJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBATCHJOBSRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.ListBatchJobsResponse)
  })
_sym_db.RegisterMessage(ListBatchJobsResponse)

CreateBatchJobRequest = _reflection.GeneratedProtocolMessageType('CreateBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.CreateBatchJobRequest)
  })
_sym_db.RegisterMessage(CreateBatchJobRequest)

CreateBatchJobResponse = _reflection.GeneratedProtocolMessageType('CreateBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.CreateBatchJobResponse)
  })
_sym_db.RegisterMessage(CreateBatchJobResponse)

DeleteBatchJobRequest = _reflection.GeneratedProtocolMessageType('DeleteBatchJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.DeleteBatchJobRequest)
  })
_sym_db.RegisterMessage(DeleteBatchJobRequest)

DeleteBatchJobResponse = _reflection.GeneratedProtocolMessageType('DeleteBatchJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBATCHJOBRESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.DeleteBatchJobResponse)
  })
_sym_db.RegisterMessage(DeleteBatchJobResponse)

UpdateBatchJobStateRequest = _reflection.GeneratedProtocolMessageType('UpdateBatchJobStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHJOBSTATEREQUEST,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateRequest)
  })
_sym_db.RegisterMessage(UpdateBatchJobStateRequest)

UpdateBatchJobStateResponse = _reflection.GeneratedProtocolMessageType('UpdateBatchJobStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBATCHJOBSTATERESPONSE,
  '__module__' : 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateResponse)
  })
_sym_db.RegisterMessage(UpdateBatchJobStateResponse)

_BATCHJOBSSERVICE = DESCRIPTOR.services_by_name['BatchJobsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.batch_jobs.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobs'
  _GETBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _GETBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\340A\002'
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._serialized_options = b'\340A\002'
  _GETBATCHJOBREQUEST._serialized_start=164
  _GETBATCHJOBREQUEST._serialized_end=244
  _GETBATCHJOBRESPONSE._serialized_start=246
  _GETBATCHJOBRESPONSE._serialized_end=330
  _LISTBATCHJOBSREQUEST._serialized_start=332
  _LISTBATCHJOBSREQUEST._serialized_end=403
  _LISTBATCHJOBSRESPONSE._serialized_start=405
  _LISTBATCHJOBSRESPONSE._serialized_end=487
  _CREATEBATCHJOBREQUEST._serialized_start=489
  _CREATEBATCHJOBREQUEST._serialized_end=575
  _CREATEBATCHJOBRESPONSE._serialized_start=577
  _CREATEBATCHJOBRESPONSE._serialized_end=664
  _DELETEBATCHJOBREQUEST._serialized_start=666
  _DELETEBATCHJOBREQUEST._serialized_end=749
  _DELETEBATCHJOBRESPONSE._serialized_start=751
  _DELETEBATCHJOBRESPONSE._serialized_end=775
  _UPDATEBATCHJOBSTATEREQUEST._serialized_start=778
  _UPDATEBATCHJOBSTATEREQUEST._serialized_end=940
  _UPDATEBATCHJOBSTATERESPONSE._serialized_start=942
  _UPDATEBATCHJOBSTATERESPONSE._serialized_end=971
  _BATCHJOBSSERVICE._serialized_start=974
  _BATCHJOBSSERVICE._serialized_end=1631
# @@protoc_insertion_point(module_scope)
