# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\"\x1e\n\x1cGetBatchExporterImageRequest\"W\n\x1dGetBatchExporterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1e\n\x1cGetKafkaExporterImageRequest\"3\n\x1dGetKafkaExporterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x1a\n\x18GetDecrypterImageRequest\"S\n\x19GetDecrypterImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\"\x1f\n\x1dGetBatchJobRunnerImageRequest\"X\n\x1eGetBatchJobRunnerImageResponse\x12\x12\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x03\xe0\x41\x02\x32\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')



_GETBATCHEXPORTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetBatchExporterImageRequest']
_GETBATCHEXPORTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetBatchExporterImageResponse']
_GETKAFKAEXPORTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetKafkaExporterImageRequest']
_GETKAFKAEXPORTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetKafkaExporterImageResponse']
_GETDECRYPTERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetDecrypterImageRequest']
_GETDECRYPTERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetDecrypterImageResponse']
_GETBATCHJOBRUNNERIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetBatchJobRunnerImageRequest']
_GETBATCHJOBRUNNERIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetBatchJobRunnerImageResponse']
GetBatchExporterImageRequest = _reflection.GeneratedProtocolMessageType('GetBatchExporterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest)
  })
_sym_db.RegisterMessage(GetBatchExporterImageRequest)

GetBatchExporterImageResponse = _reflection.GeneratedProtocolMessageType('GetBatchExporterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHEXPORTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse)
  })
_sym_db.RegisterMessage(GetBatchExporterImageResponse)

GetKafkaExporterImageRequest = _reflection.GeneratedProtocolMessageType('GetKafkaExporterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest)
  })
_sym_db.RegisterMessage(GetKafkaExporterImageRequest)

GetKafkaExporterImageResponse = _reflection.GeneratedProtocolMessageType('GetKafkaExporterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETKAFKAEXPORTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse)
  })
_sym_db.RegisterMessage(GetKafkaExporterImageResponse)

GetDecrypterImageRequest = _reflection.GeneratedProtocolMessageType('GetDecrypterImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDECRYPTERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest)
  })
_sym_db.RegisterMessage(GetDecrypterImageRequest)

GetDecrypterImageResponse = _reflection.GeneratedProtocolMessageType('GetDecrypterImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDECRYPTERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse)
  })
_sym_db.RegisterMessage(GetDecrypterImageResponse)

GetBatchJobRunnerImageRequest = _reflection.GeneratedProtocolMessageType('GetBatchJobRunnerImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRUNNERIMAGEREQUEST,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest)
  })
_sym_db.RegisterMessage(GetBatchJobRunnerImageRequest)

GetBatchJobRunnerImageResponse = _reflection.GeneratedProtocolMessageType('GetBatchJobRunnerImageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBATCHJOBRUNNERIMAGERESPONSE,
  '__module__' : 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponse)
  })
_sym_db.RegisterMessage(GetBatchJobRunnerImageResponse)

_CUSTOMERENTITYVERSIONSSERVICE = DESCRIPTOR.services_by_name['CustomerEntityVersionsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=159
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=189
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=191
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=278
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=280
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=310
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=312
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=363
  _GETDECRYPTERIMAGEREQUEST._serialized_start=365
  _GETDECRYPTERIMAGEREQUEST._serialized_end=391
  _GETDECRYPTERIMAGERESPONSE._serialized_start=393
  _GETDECRYPTERIMAGERESPONSE._serialized_end=476
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=478
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=509
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=511
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=599
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=602
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1332
# @@protoc_insertion_point(module_scope)
