# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/installations/v1/installations_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\"6\n\x16GetInstallationRequest\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\"d\n\x17GetInstallationResponse\x12I\n\x0cinstallation\x18\x01 \x01(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02\"\x1a\n\x18ListInstallationsRequest\"g\n\x19ListInstallationsResponse\x12J\n\rinstallations\x18\x01 \x03(\x0b\x32..strmprivacy.api.installations.v1.InstallationB\x03\xe0\x41\x02\"8\n\x1dGetProjectInstallationRequest\x12\x17\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\">\n\x1eGetProjectInstallationResponse\x12\x1c\n\x0finstallation_id\x18\x01 \x01(\tB\x03\xe0\x41\x02\x32\xcc\x03\n\x14InstallationsService\x12\x86\x01\n\x0fGetInstallation\x12\x38.strmprivacy.api.installations.v1.GetInstallationRequest\x1a\x39.strmprivacy.api.installations.v1.GetInstallationResponse\x12\x8c\x01\n\x11ListInstallations\x12:.strmprivacy.api.installations.v1.ListInstallationsRequest\x1a;.strmprivacy.api.installations.v1.ListInstallationsResponse\x12\x9b\x01\n\x16GetProjectInstallation\x12?.strmprivacy.api.installations.v1.GetProjectInstallationRequest\x1a@.strmprivacy.api.installations.v1.GetProjectInstallationResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')



_GETINSTALLATIONREQUEST = DESCRIPTOR.message_types_by_name['GetInstallationRequest']
_GETINSTALLATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetInstallationResponse']
_LISTINSTALLATIONSREQUEST = DESCRIPTOR.message_types_by_name['ListInstallationsRequest']
_LISTINSTALLATIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListInstallationsResponse']
_GETPROJECTINSTALLATIONREQUEST = DESCRIPTOR.message_types_by_name['GetProjectInstallationRequest']
_GETPROJECTINSTALLATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetProjectInstallationResponse']
GetInstallationRequest = _reflection.GeneratedProtocolMessageType('GetInstallationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLATIONREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstallationRequest)
  })
_sym_db.RegisterMessage(GetInstallationRequest)

GetInstallationResponse = _reflection.GeneratedProtocolMessageType('GetInstallationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTALLATIONRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetInstallationResponse)
  })
_sym_db.RegisterMessage(GetInstallationResponse)

ListInstallationsRequest = _reflection.GeneratedProtocolMessageType('ListInstallationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLATIONSREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstallationsRequest)
  })
_sym_db.RegisterMessage(ListInstallationsRequest)

ListInstallationsResponse = _reflection.GeneratedProtocolMessageType('ListInstallationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTALLATIONSRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.ListInstallationsResponse)
  })
_sym_db.RegisterMessage(ListInstallationsResponse)

GetProjectInstallationRequest = _reflection.GeneratedProtocolMessageType('GetProjectInstallationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTINSTALLATIONREQUEST,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetProjectInstallationRequest)
  })
_sym_db.RegisterMessage(GetProjectInstallationRequest)

GetProjectInstallationResponse = _reflection.GeneratedProtocolMessageType('GetProjectInstallationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTINSTALLATIONRESPONSE,
  '__module__' : 'strmprivacy.api.installations.v1.installations_v1_pb2'
  # @@protoc_insertion_point(class_scope:strmprivacy.api.installations.v1.GetProjectInstallationResponse)
  })
_sym_db.RegisterMessage(GetProjectInstallationResponse)

_INSTALLATIONSSERVICE = DESCRIPTOR.services_by_name['InstallationsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLATIONREQUEST.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._options = None
  _GETINSTALLATIONRESPONSE.fields_by_name['installation']._serialized_options = b'\340A\002'
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._options = None
  _LISTINSTALLATIONSRESPONSE.fields_by_name['installations']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTINSTALLATIONREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._options = None
  _GETPROJECTINSTALLATIONRESPONSE.fields_by_name['installation_id']._serialized_options = b'\340A\002'
  _GETINSTALLATIONREQUEST._serialized_start=178
  _GETINSTALLATIONREQUEST._serialized_end=232
  _GETINSTALLATIONRESPONSE._serialized_start=234
  _GETINSTALLATIONRESPONSE._serialized_end=334
  _LISTINSTALLATIONSREQUEST._serialized_start=336
  _LISTINSTALLATIONSREQUEST._serialized_end=362
  _LISTINSTALLATIONSRESPONSE._serialized_start=364
  _LISTINSTALLATIONSRESPONSE._serialized_end=467
  _GETPROJECTINSTALLATIONREQUEST._serialized_start=469
  _GETPROJECTINSTALLATIONREQUEST._serialized_end=525
  _GETPROJECTINSTALLATIONRESPONSE._serialized_start=527
  _GETPROJECTINSTALLATIONRESPONSE._serialized_end=589
  _INSTALLATIONSSERVICE._serialized_start=592
  _INSTALLATIONSSERVICE._serialized_end=1052
# @@protoc_insertion_point(module_scope)
